@@ -9,30 +9,21 @@ test_that("crosswin produces output", {
   data(Mass, envir = environment())
   data(MassClimate, envir = environment())
   
+  test <- crosswin(xvar = list(Temp = MassClimate$Temp), 
+                   xvar2 = list(Rain = MassClimate$Rain), 
+                   cdate = MassClimate$Date,
+                   bdate = Mass$Date, furthest = 2, closest = 1, 
+                   stat = "max", stat2 = "max", type = "variable",
+                   cmissing = FALSE, cinterval = "day")
+  
   furthest = 2
   closest = 1
-  STAT = "max"
-  
-  test <- crosswin(Xvar = MassClimate$Temp, Xvar2 = MassClimate$Rain, CDate = MassClimate$Date,
-           BDate = Mass$Date, furthest = 2, closest = 1, 
-           STAT = "max", FIXED = FALSE,
-           CMISSING = FALSE, CINTERVAL = "D")
-  
-  MaxMODNO <- 0
-  duration <- (furthest-closest) + 1
-  for (m in closest:furthest){
-    for (n in 1:duration){
-      if ((m-n)>=(closest-1)){  
-        if (STAT!="slope" || n>1){
-          MaxMODNO <- MaxMODNO + 1
-        }
-      }
-    }
-  }
+  duration  <- (furthest - closest) + 1
+  maxmodno  <- (duration * (duration + 1))/2
   
   expect_true(is.data.frame(test))
   expect_equal(length(which(is.na(test))), 0)
   expect_true(ncol(test) >= 7)
-  expect_equal(MaxMODNO, nrow(test))
+  expect_equal(maxmodno, nrow(test))
   
 })
\ No newline at end of file
